from zope.interface import Interface
from plone.theme.interfaces import IDefaultPloneLayer
from zope.viewlet.interfaces import IViewletManager
from zope import schema
from plone.portlets.interfaces import IPortletManager
from plone.app.portlets.interfaces import IColumn

"""
Base interfaces for further development and to adapt and extend theme
for particular websites
"""

class IMediaTypes(Interface):
    """
    Marks all Media types from Products.media*
    """

class IThemeSpecific(Interface):
    """Marker interface that defines a Zope 3 browser layer.
    """

class IFooterPortlet(IColumn):
    """we need our own portlet manager for the footer.
    """

class IPagePortlet(IColumn):
    """we need our own portlet manager for the footer.
    """

class ICollectionPortletManager(IColumn):
    """we need our own portlet manager for the footer.
    """
    


from Acquisition import aq_inner
from zope.interface import alsoProvides
from z3c.form.interfaces import IFormLayer
from plone.z3cform.interfaces import IWrappedForm
from plone.z3cform import z2
from Products.CMFCore.utils import getToolByName
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile

from zope.interface import implements
from zope import schema

from z3c.form import field
from z3c.form.browser.checkbox import CheckBoxFieldWidget

from plone.memoize.compress import xhtml_compress
from plone.memoize.instance import memoize

from plone.portlets.interfaces import IPortletDataProvider

from plone.app.portlets import PloneMessageFactory as _
from plone.app.portlets.portlets import base

from collective.mailchimp.browser.z3cformhelpers import AddForm
from collective.mailchimp.browser.z3cformhelpers import EditForm

from collective.mailchimp.interfaces import INewsletterSubscribe
from collective.mailchimp.browser.newsletter import NewsletterSubscriberForm


class IExtendedMailChimp(IPortletDataProvider):

    name = schema.TextLine(
        title=_(u'Title'),
        description=_(u'Title of the portlet'))

    description = schema.TextLine(
        title=_(u'Description'),
        description=_(u'Description of the portlet'))

    available_lists = schema.List(
        title=_(u'Available lists'),
        description=_(u'Select available lists to subscribe to.'),
        required=True,
        min_length=1,
        value_type=schema.Choice(
            source='collective.mailchimp.vocabularies.AvailableLists'
            )
        )


class Assignment(base.Assignment):
    implements(IExtendedMailChimp)

    def __init__(self, name=u'', description=u'', available_lists=[]):
        self.name = name
        self.description = description
        self.available_lists = available_lists

    @property
    def title(self):
        return _(u"MailChimp")


class Renderer(base.Renderer):
    fields = field.Fields(INewsletterSubscribe)
    _template = ViewPageTemplateFile('alternative_templates/portlet.pt')
    form = NewsletterSubscriberForm

    def __init__(self, *args):
        base.Renderer.__init__(self, *args)

    def render(self):
        return xhtml_compress(self._template())

    @property
    def name(self):
        return self.data.name or _(u"Subscribe to newsletter")

    @property
    def description(self):
        return self.data.description or _(u"")

    @memoize
    def _data(self):
        catalog = getToolByName(self.context, 'portal_catalog')
        return catalog(portal_type='MailChimp Item')

    def update(self):
        super(Renderer, self).update()
        z2.switch_on(self, request_layer=IFormLayer)
        self.form = self.form(aq_inner(self.context), self.request)
        alsoProvides(self.form, IWrappedForm)
        self.form.update()


class AddForm(AddForm):
    fields = field.Fields(IExtendedMailChimp)
    fields['available_lists'].widgetFactory = CheckBoxFieldWidget
    label = _(u"Add MailChimp Portlet")
    description = _(
        u"This portlet displays a subscription form for a " +
        u"MailChimp newsletter.")

    def create(self, data):
        return Assignment(
            name=data.get('name', u''),
            description=data.get('description', u''),
            available_lists=data.get('available_lists', []))


class EditForm(EditForm):
    fields = field.Fields(IExtendedMailChimp)
    fields['available_lists'].widgetFactory = CheckBoxFieldWidget
    label = _(u"Edit MailChimp Portlet")
    description = _(
        u"This portlet displays a subscription form for a " +
        u"MailChimp newsletter.")




  # -*- extra stuff goes here -*- 
# Initial permissions setup.
import permissions
from zope.i18nmessageid import MessageFactory as BaseMessageFactory

MessageFactory = BaseMessageFactory('plonetheme.bootstrapModern')

def initialize(context):
    """Initializer called when used as a Zope 2 product."""




from setuptools import setup, find_packages
import os

version = '0.34'

setup(name='plonetheme.bootstrapModern',
      version=version,
      description="An installable theme for Plone 4",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        ],
      keywords='web zope plone theme',
      author='Andre Goncalves',
      author_email='andre@intk.com',
      url='http://svn.plone.org/svn/collective/',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['plonetheme'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'plone.app.z3cform',
      ],
      entry_points="""
      # -*- Entry points: -*-

      [z3c.autoinclude.plugin]
      target = plone
      """,
      setup_requires=["PasteScript"],
      paster_plugins=["ZopeSkel"],
      )
